<?php

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

$app->get('/login', function() use ($app) {
    return $app['twig']->render('login.html.twig');
});

$app->post('/login', function(Request $request) use ($app, $config) {
    $pw = $request->get('pw', false);
	$user = $request->get('user', false);

    if (array_key_exists($user, $config['users']) && $config['users'][$user]['pw'] === $pw) {
        $app['session']->set('authenticated', true);
        $app['session']->set('user', $user);
        return $app->redirect('/');
    }
	
    return $app['twig']->render('login.html.twig');
});

$app->get('/logout', function() use ($app) {
    $app['session']->set('authenticated', false);
    $app['session']->set('user', '');
    return $app->redirect('/index.php/login');
});

$app->get('/', function() use ($app) {
    if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }

    return $app['twig']->render('index.html.twig');
});


/* 1 LAYER */

$app->get('/1layer', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$1layer = $app['db']->fetchAll("SELECT * FROM 1layer");
	
	return $app['twig']->render('1layer/index.html.twig', array(
		'1layer'	=> $1layer
	));
});

$app->get('/1layer/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = array(
		'id'				=> 0,
		'title'				=> '',
		'subtitle'			=> '',
		'description'		=> '',
		'picture'			=> '',
		'titleError'		=> false,
		'subtitleError'		=> false,
		'descriptionError'	=> false,
		'pictureError'		=> false,
		'new'				=> true
	);
	
	return $app['twig']->render('1layer/new.html.twig', array(
		'data' 	=> $data
	));
});

$app->post('/1layer/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['subtitleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$files = $request->files->get('data');

	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['subtitle'] == '') {
		$data['subtitleError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if (!isset($files['picture'])) {
		$data['pictureError'] = true;
	}
	if ($data['titleError'] || $data['subtitleError'] || $data['descriptionError'] || $data['pictureError']) {
		return $app['twig']->render('1layer/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->insert('1layer', array(
		'title'			=> $data['title'],
		'subtitle'		=> $data['subtitle'],
		'description'	=> $data['description']
	));
	$id = $app['db']->lastInsertId();
	
	$bild = $files['picture'];
	$app['db']->update('1layer', array(
		'picture'	=> 'data:'.$bild->getClientMimeType().';base64,'.base64_encode(file_get_contents($bild->getRealPath()))
	), array(
		'id' => $id
	));
	
	return $app->redirect('/index.php/1layer');
});

$app->get('/1layer/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM 1layer WHERE id = ? LIMIT 1", array($id));
	$data['titleError'] = false;
	$data['subtitleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$data['new'] = false;
	
	return $app['twig']->render('1layer/new.html.twig', array(
		'data'	=> $data
	));
});

$app->post('/1layer/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['picture'] = '';
	$data['titleError'] = false;
	$data['subtitleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	
	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['subtitle'] == '') {
		$data['subtitleError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if ($data['titleError'] || $data['subtitleError'] || $data['descriptionError']) {
		return $app['twig']->render('1layer/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->update('1layer', array(
		'title'			=> $data['title'],
		'subtitle'		=> $data['subtitle'],
		'description'	=> $data['description']
	), array(
		'id' => $data['id']
	));
	
		
	$files = $request->files->get('data');
	if (isset($files['picture'])) {
		$picture = $files['picture'];
		$app['db']->update('1layer', array(
			'picture'	=> 'data:'.$picture->getClientMimeType().';base64,'.base64_encode(file_get_contents($picture->getRealPath()))
		), array(
			'id' => $data['id']
		));
	}
	
	return $app->redirect('/index.php/1layer');
});

$app->get('/1layer/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('1layer', array('id' => $id));
	
	return $app->redirect('/index.php/1layer');
});


/* GRID */

$app->get('/grid', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$grid = $app['db']->fetchAll("SELECT * FROM grid ORDER BY ordering ASC");
	
	return $app['twig']->render('grid/index.html.twig', array(
		'grid'	=> $grid
	));
});

$app->get('/grid/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$ordering = $app['db']->fetchAssoc("SELECT MAX(ordering) as ordering FROM grid");
	
	$data = array(
		'id'				=> 0,
		'title'				=> '',
		'description'		=> '',
		'picture'			=> '',
		'ordering'			=> $ordering['ordering'] + 1,
		'titleError'		=> false,
		'descriptionError'	=> false,
		'pictureError'		=> false,
		'new'				=> true
	);
	
	return $app['twig']->render('grid/new.html.twig', array(
		'data' 	=> $data
	));
});

$app->post('/grid/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$files = $request->files->get('data');

	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if (!isset($files['picture'])) {
		$data['pictureError'] = true;
	}
	if ($data['titleError'] || $data['descriptionError'] || $data['pictureError']) {
		return $app['twig']->render('grid/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->insert('grid', array(
		'title'			=> $data['title'],
		'description'	=> $data['description'],
		'ordering' 		=> $data['ordering']
	));
	$id = $app['db']->lastInsertId();
	
	$bild = $files['picture'];
	$app['db']->update('grid', array(
		'picture'	=> 'data:'.$bild->getClientMimeType().';base64,'.base64_encode(file_get_contents($bild->getRealPath()))
	), array(
		'id' => $id
	));
	
	return $app->redirect('/index.php/grid');
});

$app->get('/grid/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM grid WHERE id = ? LIMIT 1", array($id));
	$data['titleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$data['new'] = false;
	
	return $app['twig']->render('grid/new.html.twig', array(
		'data'	=> $data
	));
});

$app->post('/grid/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['picture'] = '';
	$data['titleError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	
	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if ($data['titleError'] || $data['descriptionError']) {
		return $app['twig']->render('grid/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->update('grid', array(
		'title'			=> $data['title'],
		'description'	=> $data['description'],
		'ordering' 		=> $data['ordering']
	), array(
		'id' => $data['id']
	));
	
		
	$files = $request->files->get('data');
	if (isset($files['picture'])) {
		$picture = $files['picture'];
		$app['db']->update('grid', array(
			'picture'	=> 'data:'.$picture->getClientMimeType().';base64,'.base64_encode(file_get_contents($picture->getRealPath()))
		), array(
			'id' => $data['id']
		));
	}
	
	return $app->redirect('/index.php/grid');
});

$app->get('/grid/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('grid', array('id' => $id));
	
	return $app->redirect('/index.php/grid');
});


/* PICTURES */

$app->get('/pictures', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$pictures = $app['db']->fetchAll("SELECT * FROM pictures ORDER BY ordering ASC");
	
	$workUnsorted = $app['db']->fetchAll("SELECT * FROM work");
	$works = Array();
	foreach ($workUnsorted as $work) {
		$works[$work['id']] = $work;
	}
	
	return $app['twig']->render('pictures/index.html.twig', array(
		'pictures'	=> $pictures,
		'works'		=> $works
	));
});

$app->get('/pictures/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$ordering = $app['db']->fetchAssoc("SELECT MAX(ordering) as ordering FROM pictures");
	$works = $app['db']->fetchAll("SELECT * FROM work");
	
	$data = array(
		'id'				=> 0,
		'picture'			=> '',
		'ordering'			=> $ordering['ordering'] + 1,
		'work_id'			=> 1,
		'pictureError'		=> false,
		'new'				=> true
	);
	
	return $app['twig']->render('pictures/new.html.twig', array(
		'data' 		=> $data,
		'works' 	=> $works
	));
});

$app->post('/pictures/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['pictureError'] = false;
	$files = $request->files->get('data');

	if (!isset($files['picture'])) {
		$data['pictureError'] = true;
	}
	if ($data['pictureError']) {
		$works = $app['db']->fetchAll("SELECT * FROM work");
		return $app['twig']->render('pictures/new.html.twig', array(
			'data'	=> $data,
			'works'	=> $works
		));
	}
	
	$app['db']->insert('pictures', array(
		'ordering' 	=> $data['ordering'],
		'work_id' 	=> $data['work_id']
	));
	$id = $app['db']->lastInsertId();
	
	$picture = $files['picture'];
	$app['db']->update('pictures', array(
		'picture'	=> 'data:'.$picture->getClientMimeType().';base64,'.base64_encode(file_get_contents($picture->getRealPath()))
	), array(
		'id' => $id
	));
	
	return $app->redirect('/index.php/pictures');
});

$app->get('/pictures/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM pictures WHERE id = ? LIMIT 1", array($id));
	$data['pictureError'] = false;
	$data['new'] = false;
	
	$works = $app['db']->fetchAll("SELECT * FROM work");
	
	return $app['twig']->render('pictures/new.html.twig', array(
		'data'	=> $data,
		'works'	=> $works
	));
});

$app->post('/pictures/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['picture'] = '';
	$data['pictureError'] = false;
		
	$app['db']->update('pictures', array(
		'ordering' 	=> $data['ordering'],
		'work_id'	=> $data['work_id']
	), array(
		'id' => $data['id']
	));
	
		
	$files = $request->files->get('data');
	if (isset($files['picture'])) {
		$picture = $files['picture'];
		$app['db']->update('pictures', array(
			'picture'	=> 'data:'.$picture->getClientMimeType().';base64,'.base64_encode(file_get_contents($picture->getRealPath()))
		), array(
			'id' => $data['id']
		));
	}
	
	return $app->redirect('/index.php/pictures');
});

$app->get('/pictures/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('pictures', array('id' => $id));
	
	return $app->redirect('/index.php/pictures');
});


/* VIDEOS */

$app->get('/videos', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$videos = $app['db']->fetchAll("SELECT * FROM videos ORDER BY ordering ASC");
	
	$workUnsorted = $app['db']->fetchAll("SELECT * FROM work");
	$works = Array();
	foreach ($workUnsorted as $work) {
		$works[$work['id']] = $work;
	}
	
	return $app['twig']->render('videos/index.html.twig', array(
		'videos'	=> $videos,
		'works'		=> $works
	));
});

$app->get('/videos/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$ordering = $app['db']->fetchAssoc("SELECT MAX(ordering) as ordering FROM videos");
	$works = $app['db']->fetchAll("SELECT * FROM work");
	
	$data = array(
		'id'				=> 0,
		'link'			=> '',
		'ordering'			=> $ordering['ordering'] + 1,
		'work_id'			=> 1,
		'linkError'		=> false,
		'new'				=> true
	);
	
	return $app['twig']->render('videos/new.html.twig', array(
		'data' 		=> $data,
		'works' 	=> $works
	));
});

$app->post('/videos/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['linkError'] = false;

	if ($data['link'] == '') {
		$data['linkError'] = true;
	}
	if ($data['linkError']) {
		$works = $app['db']->fetchAll("SELECT * FROM work");
		return $app['twig']->render('videos/new.html.twig', array(
			'data'	=> $data,
			'works'	=> $works
		));
	}
	
	$app['db']->insert('videos', array(
		'link' 		=> $data['link'],
		'ordering' 	=> $data['ordering'],
		'work_id' 	=> $data['work_id']
	));
	
	return $app->redirect('/index.php/videos');
});

$app->get('/videos/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM videos WHERE id = ? LIMIT 1", array($id));
	$data['linkError'] = false;
	$data['new'] = false;
	
	$works = $app['db']->fetchAll("SELECT * FROM work");
	
	return $app['twig']->render('videos/new.html.twig', array(
		'data'	=> $data,
		'works'	=> $works
	));
});

$app->post('/videos/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['linkError'] = false;
	
	if ($data['link'] == '') {
		$data['linkError'] = true;
	}
	if ($data['linkError']) {
		$works = $app['db']->fetchAll("SELECT * FROM work");
		return $app['twig']->render('videos/new.html.twig', array(
			'data'	=> $data,
			'works'	=> $works
		));
	}
		
	$app['db']->update('videos', array(
		'link' 		=> $data['link'],
		'ordering' 	=> $data['ordering'],
		'work_id'	=> $data['work_id']
	), array(
		'id' => $data['id']
	));
	
	return $app->redirect('/index.php/videos');
});

$app->get('/videos/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('videos', array('id' => $id));
	
	return $app->redirect('/index.php/videos');
});


/* LIST */

$app->get('/list', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$list = $app['db']->fetchAll("SELECT * FROM list ORDER BY ordering ASC");
	
	return $app['twig']->render('list/index.html.twig', array(
		'list'	=> $list
	));
});

$app->get('/list/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$ordering = $app['db']->fetchAssoc("SELECT MAX(ordering) as ordering FROM list");
	
	$data = array(
		'id'				=> 0,
		'title'				=> '',
		'pretext'			=> '',
		'description'		=> '',
		'picture'			=> '',
		'ordering'			=> $ordering['ordering'] + 1,
		'titleError'		=> false,
		'pretextError'		=> false,
		'descriptionError'	=> false,
		'pictureError'		=> false,
		'new'				=> true
	);
	
	return $app['twig']->render('list/new.html.twig', array(
		'data' 	=> $data
	));
});

$app->post('/list/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['pretextError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$files = $request->files->get('data');

	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['pretext'] == '') {
		$data['pretextError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if (!isset($files['picture'])) {
		$data['pictureError'] = true;
	}
	if ($data['titleError'] || $data['pretextError'] ||  $data['descriptionError'] || $data['pictureError']) {
		return $app['twig']->render('list/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->insert('list', array(
		'title'			=> $data['title'],
		'pretext'		=> $data['pretext'],
		'description'	=> $data['description'],
		'ordering' 		=> $data['ordering']
	));
	$id = $app['db']->lastInsertId();
	
	$bild = $files['picture'];
	$app['db']->update('list', array(
		'picture'	=> 'data:'.$bild->getClientMimeType().';base64,'.base64_encode(file_get_contents($bild->getRealPath()))
	), array(
		'id' => $id
	));
	
	return $app->redirect('/index.php/list');
});

$app->get('/list/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM list WHERE id = ? LIMIT 1", array($id));
	$data['titleError'] = false;
	$data['pretextError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	$data['new'] = false;
	
	return $app['twig']->render('list/new.html.twig', array(
		'data'	=> $data
	));
});

$app->post('/list/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['picture'] = '';
	$data['titleError'] = false;
	$data['pretextError'] = false;
	$data['descriptionError'] = false;
	$data['pictureError'] = false;
	
	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['pretext'] == '') {
		$data['pretextError'] = true;
	}
	if ($data['description'] == '') {
		$data['descriptionError'] = true;
	}
	if ($data['titleError'] || $data['pretextError'] || $data['descriptionError']) {
		return $app['twig']->render('list/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$app['db']->update('list', array(
		'title'			=> $data['title'],
		'pretext'		=> $data['pretext'],
		'description'	=> $data['description'],
		'ordering' 		=> $data['ordering']
	), array(
		'id' => $data['id']
	));
	
		
	$files = $request->files->get('data');
	if (isset($files['picture'])) {
		$picture = $files['picture'];
		$app['db']->update('list', array(
			'picture'	=> 'data:'.$picture->getClientMimeType().';base64,'.base64_encode(file_get_contents($picture->getRealPath()))
		), array(
			'id' => $data['id']
		));
	}
	
	return $app->redirect('/index.php/list');
});

$app->get('/list/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('list', array('id' => $id));
	
	return $app->redirect('/index.php/list');
});


/* USERS */

$app->get('/users', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	
	return $app['twig']->render('users/index.html.twig', array(
		'users'		=> $users
	));
});

$app->get('/users/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = array(
		'id'			=> 0,
		'username'		=> '',
		'password'		=> '',
		'salt'			=> '',
		'usernameError'	=> false,
		'passwordError'	=> false,
		'new'			=> true
	);
	
	return $app['twig']->render('users/new.html.twig', array(
		'data' 	=> $data
	));
});

$app->post('/users/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['usernameError'] = false;
	$data['passwordError'] = false;

	if ($data['username'] == '') {
		$data['usernameError'] = true;
	}
	if ($data['password'] == '') {
		$data['passwordError'] = true;
	}
	if ($data['usernameError'] || $data['passwordError']) {
		return $app['twig']->render('users/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	$salt = substr(md5(microtime()),rand(0,26),10);

	$app['db']->insert('users', array(
		'username'		=> $data['username'],
		'password'		=> crypt($data['password'], $salt),
		'salt'			=> $salt
	));

	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	
	return $app['twig']->render('users/index.html.twig', array(
		'users'		=> $users
	));
});

$app->get('/users/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM users WHERE id = ? LIMIT 1", array($id));
	$data['usernameError'] = false;
	$data['passwordError'] = false;
	$data['new'] = false;

	return $app['twig']->render('users/new.html.twig', array(
		'data'	=> $data
	));
});

$app->post('/users/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['usernameError'] = false;
	$data['passwordError'] = false;

	if ($data['username'] == '') {
		$data['usernameError'] = true;
	}
	if ($data['usernameError']) {
		return $app['twig']->render('users/new.html.twig', array(
			'data'	=> $data
		));
	}
	
	if($data['password'] != '') {
		$salt = substr(md5(microtime()),rand(0,26),10);
		$app['db']->update('users', array(
			'username' 	=> $data['username'],
			'password'	=> crypt($data['password'], $salt),
			'salt'		=> $salt
		), array(
			'id' => $data['id']
		));
	}
	else {
		$app['db']->update('users', array(
			'username' 	=> $data['username']
		), array(
			'id' => $data['id']
		));
	}
		
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	
	return $app['twig']->render('users/index.html.twig', array(
		'users'		=> $users
	));
});

$app->get('/users/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('users', array('id' => $id));
	
	return $app->redirect('/index.php/users');
});


/* CALENDAR */

$app->get('/calendar/page={site}', function($site) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$page = ($site-1) * 10;
	$count = $app['db']->fetchAll("SELECT * FROM calendar");
	$calendar = $app['db']->fetchAll("SELECT * FROM calendar ORDER BY user_id ASC, date DESC LIMIT $page, 10");
		
	$usersUnsorted = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	$users = Array();
	foreach ($usersUnsorted as $user) {
		$users[$user['id']] = $user;
	}
	
	$count = ceil(count($count)/10);
	
	return $app['twig']->render('calendar/index.html.twig', array(
		'calendar'	=> $calendar,
		'users'		=> $users,
		'count'		=> $count,
		'page'		=> $site
	));
});

$app->get('/calendar/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$today = date('d.m.Y');
	$todayHidden = date('Y-m-d');
	$data = array(
		'id'				=> 0,
		'title'				=> '',
		'description'		=> '',
		'user_id'			=> 0,
		'date'				=> $today,
		'dateHidden'		=> $todayHidden,
		'titleError'		=> false,
		'dateError'			=> false,
		'new'				=> true
	);
	
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	return $app['twig']->render('calendar/new.html.twig', array(
		'data' 			=> $data,
		'users'			=> $users
	));
});

$app->post('/calendar/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['dateError'] = false;

	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['date'] == '') {
		$data['dateError'] = true;
	}
	if ($data['titleError'] || $data['dateError']) {
		$today = date('d.m.Y');
		$todayHidden = date('Y-m-d');
		$data['date'] = $today;
		$data['dateHidden'] = $todayHidden;
		$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
		return $app['twig']->render('calendar/new.html.twig', array(
			'data'	=> $data,
			'users'	=> $users
		));
	}
	
	$app['db']->insert('calendar', array(
		'title'			=> $data['title'],
		'date'			=> $data['date'],
		'description'	=> $data['description'],
		'user_id'		=> $data['user_id']
	));
	
	return $app->redirect('/index.php/calendar/page=1');
});

$app->get('/calendar/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM calendar WHERE id = ? LIMIT 1", array($id));
	
	$data['dateHidden'] = $data['date'];
	$date = new DateTime($data['date']);
	$data['date'] = date_format($date, 'd.m.Y');
	$data['titleError'] = false;
	$data['dateError'] = false;
	$data['new'] = false;
	
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	return $app['twig']->render('calendar/new.html.twig', array(
		'data'			=> $data,
		'users'			=> $users
	));
});

$app->post('/calendar/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['dateError'] = false;
	
	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['date'] == '') {
		$data['dateError'] = true;
	}
	if ($data['titleError'] || $data['dateError']) {
		$today = date('d.m.Y');
		$todayHidden = date('Y-m-d');
		$data['date'] = $today;
		$data['dateHidden'] = $todayHidden;
		
		$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
		return $app['twig']->render('calendar/new.html.twig', array(
			'data'			=> $data,
			'users'			=> $users
		));
	}
	
	$app['db']->update('calendar', array(
		'title'			=> $data['title'],
		'date'			=> $data['date'],
		'description'	=> $data['description'],
		'user_id'		=> $data['user_id']
	), array(
		'id' => $data['id']
	));
	
	return $app->redirect('/index.php/calendar/page=1');
});

$app->get('/calendar/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('calendar', array('id' => $id));
	
	return $app->redirect('/index.php/calendar/page=1');
});


/* MAP */

$app->get('/map/page={site}', function($site) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$page = ($site-1) * 10;
	$count = $app['db']->fetchAll("SELECT * FROM calendar");
	$map = $app['db']->fetchAll("SELECT * FROM map ORDER BY user_id ASC, address ASC LIMIT $page, 10");
	
	$usersUnsorted = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	$users = Array();
	foreach ($usersUnsorted as $user) {
		$users[$user['id']] = $user;
	}
	
	$count = ceil(count($count)/10);
	
	return $app['twig']->render('map/index.html.twig', array(
		'map'	=> $map,
		'users'	=> $users,
		'count'	=> $count,
		'page'	=> $site
	));
});

$app->get('/map/new', function() use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = array(
		'id'				=> 0,
		'title'				=> '',
		'address'			=> '',
		'description'		=> '',
		'user_id'			=> 0,
		'titleError'		=> '',
		'addressError'		=> '',
		'new'				=> true
	);
	
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	return $app['twig']->render('map/new.html.twig', array(
		'data' 	=> $data,
		'users'	=> $users
	));
});

$app->post('/map/create', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['adressError'] = false;

	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['address'] == '') {
		$data['addressError'] = true;
	}
	if ($data['titleError'] || $data['addressError']) {
		$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
		return $app['twig']->render('map/new.html.twig', array(
			'data'		=> $data,
			'users'		=> $users
		));
	}
	
	$address = str_replace(" ", "+", $data['address']); // replace all the white space with "+" sign to match with google search pattern
	$url = "http://maps.google.com/maps/api/geocode/json?sensor=false&address=$address";
	$response = file_get_contents($url);
	$json = json_decode($response,TRUE); //generate array object from the response from the web
	$x = $json['results'][0]['geometry']['location']['lat'];
	$y = $json['results'][0]['geometry']['location']['lng'];
	
	$app['db']->insert('map', array(
		'title'			=> $data['title'],
		'address'		=> $data['address'],
		'x'				=> $x,
		'y'				=> $y,
		'description'	=> $data['description'],
		'user_id'		=> $data['user_id']
	));
	
	return $app->redirect('/index.php/map/page=1');
});

$app->get('/map/edit/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $app['db']->fetchAssoc("SELECT * FROM map WHERE id = ? LIMIT 1", array($id));
	$data['titleError'] = false;
	$data['addressError'] = false;
	$data['xError'] = false;
	$data['yError'] = false;
	$data['new'] = false;
	
	$users = $app['db']->fetchAll("SELECT * FROM users ORDER BY username ASC");
	return $app['twig']->render('map/new.html.twig', array(
		'data'	=> $data,
		'users'	=> $users
	));
});

$app->post('/map/update', function(Request $request) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$data = $request->get('data');
	$data['titleError'] = false;
	$data['addressError'] = false;
	$data['xError'] = false;
	$data['yError'] = false;
	
	if ($data['title'] == '') {
		$data['titleError'] = true;
	}
	if ($data['address'] == '') {
		$data['addressError'] = true;
	}
	if ($data['titleError'] || $data['addressError']) {
		return $app['twig']->render('map/new.html.twig', array(
			'data'		=> $data
		));
	}
	
	$address = str_replace(" ", "+", $data['address']); // replace all the white space with "+" sign to match with google search pattern
	$url = "http://maps.google.com/maps/api/geocode/json?sensor=false&address=$address";
	$response = file_get_contents($url);
	$json = json_decode($response,TRUE); //generate array object from the response from the web
	$x = $json['results'][0]['geometry']['location']['lat'];
	$y = $json['results'][0]['geometry']['location']['lng'];
	
	$app['db']->update('map', array(
		'title'			=> $data['title'],
		'address'		=> $data['address'],
		'x'				=> $x,
		'y'				=> $y,
		'description'	=> $data['description'],
		'user_id'		=> $data['user_id']
	), array(
		'id' => $data['id']
	));
	
	return $app->redirect('/index.php/map/page=1');
});

$app->get('/map/delete/{id}', function($id) use ($app) {
	if ($app['session']->get('authenticated', false) === false) {
        return $app->redirect('/index.php/login');
    }
	
	$app['db']->delete('map', array('id' => $id));
	
	return $app->redirect('/index.php/map/page=1');
});